package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysUserLike;
import com.ruoyi.system.domain.dto.WorkLikeDto;

/**
 * 用户点赞Service接口
 * 
 * @author haotian
 * @date 2024-12-02
 */
public interface ISysUserLikeService 
{
    /**
     * 查询用户点赞
     * 
     * @param id 用户点赞主键
     * @return 用户点赞
     */
    public SysUserLike selectSysUserLikeById(Long id);

    /**
     * 查询用户点赞列表
     * 
     * @param sysUserLike 用户点赞
     * @return 用户点赞集合
     */
    public List<SysUserLike> selectSysUserLikeList(SysUserLike sysUserLike);

    /**
     * 新增用户点赞
     * 
     * @param sysUserLike 用户点赞
     * @return 结果
     */
    public int insertSysUserLike(SysUserLike sysUserLike);

    /**
     * 修改用户点赞
     * 
     * @param sysUserLike 用户点赞
     * @return 结果
     */
    public int updateSysUserLike(SysUserLike sysUserLike);

    /**
     * 批量删除用户点赞
     * 
     * @param ids 需要删除的用户点赞主键集合
     * @return 结果
     */
    public int deleteSysUserLikeByIds(Long[] ids);

    /**
     * 删除用户点赞信息
     * 
     * @param id 用户点赞主键
     * @return 结果
     */
    public int deleteSysUserLikeById(Long id);

    /*
    * 根据userId和用户作品id, 查询给这个用户点赞的消息*/
    public List<SysUserLike> selectSysUserLikeByUserIdAndTargetId(Long userId);


}
