package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysUserLike;
import com.ruoyi.system.service.ISysUserLikeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户点赞Controller
 * 
 * @author haotian
 * @date 2024-12-02
 */
@RestController
@RequestMapping("/system/like")
public class SysUserLikeController extends BaseController
{
    @Autowired
    private ISysUserLikeService sysUserLikeService;

    /**
     * 查询用户点赞列表
     */
    @PreAuthorize("@ss.hasPermi('system:like:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysUserLike sysUserLike)
    {
        startPage();
        List<SysUserLike> list = sysUserLikeService.selectSysUserLikeList(sysUserLike);
        return getDataTable(list);
    }

    /**
     * 导出用户点赞列表
     */
    @PreAuthorize("@ss.hasPermi('system:like:export')")
    @Log(title = "用户点赞", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUserLike sysUserLike)
    {
        List<SysUserLike> list = sysUserLikeService.selectSysUserLikeList(sysUserLike);
        ExcelUtil<SysUserLike> util = new ExcelUtil<SysUserLike>(SysUserLike.class);
        util.exportExcel(response, list, "用户点赞数据");
    }

    /**
     * 获取用户点赞详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:like:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysUserLikeService.selectSysUserLikeById(id));
    }

    /**
     * 新增用户点赞
     */
    @PreAuthorize("@ss.hasPermi('system:like:add')")
    @Log(title = "用户点赞", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysUserLike sysUserLike)
    {
        return toAjax(sysUserLikeService.insertSysUserLike(sysUserLike));
    }

    /**
     * 修改用户点赞
     */
    @PreAuthorize("@ss.hasPermi('system:like:edit')")
    @Log(title = "用户点赞", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysUserLike sysUserLike)
    {
        return toAjax(sysUserLikeService.updateSysUserLike(sysUserLike));
    }

    /**
     * 删除用户点赞
     */
    @PreAuthorize("@ss.hasPermi('system:like:remove')")
    @Log(title = "用户点赞", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysUserLikeService.deleteSysUserLikeByIds(ids));
    }
}
